#!/usr/bin/env python2
# -*- coding: utf-8 -*-

import sys
import os
import multiprocessing as mp

import numpy as np
import math

#ros 
import rospy
#ros messages
from geometry_msgs.msg import Twist
from nav_msgs.msg import Odometry, Path

MIN_VELOCITY = 0.5
MAX_VELOCITY = 1.0
MIN_RADIUS = 0.5


class DubinsInterface:

    def __init__(self, velocity_in_topic_name, velocity_out_topic_name):

        self.velocity_publisher = rospy.Publisher(velocity_out_topic_name, Twist, queue_size=1)
        self.velocity_subscriber = rospy.Subscriber(velocity_in_topic_name, Twist, callback=self.velocity_callback, queue_size=1)


    def velocity_callback(self, cmd_raw):

        rospy.loginfo("%s : velocity callback" % rospy.get_name())
        cmd_dubins = Twist()
   
        velocity_linear = cmd_raw.linear.x
        velocity_angular = cmd_raw.angular.z

        velocity_linear = min(max(velocity_linear,MIN_VELOCITY),MAX_VELOCITY)
        velocity_angular =  min(max(velocity_angular,-velocity_linear/MIN_RADIUS),velocity_linear/MIN_RADIUS)

        cmd_dubins.linear.x = velocity_linear
        cmd_dubins.angular.z = velocity_angular  

        # publish the command 
        self.velocity_publisher.publish(cmd_dubins)


if __name__ == '__main__':
    
    # init ros node
    rospy.init_node('uir_dubins_robot_interface', log_level=rospy.DEBUG)
    rospy.loginfo("Starting UIR Dubins robot interdace node")
   
    # load parameters
    in_topic_name = rospy.get_param("~VELOCITY_IN_TOPIC_NAME","/robot0/cmd_vel/dubins")
    out_topic_name = rospy.get_param("~VELOCITY_OUT_TOPIC_NAME","/robot0/cmd_vel")

    # init path follower
    follower = DubinsInterface(in_topic_name,out_topic_name)


    # report loop
    rate = rospy.Rate(1)
    while not rospy.is_shutdown():
        rate.sleep()
        rospy.loginfo("%s : I am alive" % rospy.get_name())
    

