#!/usr/bin/env python2
# -*- coding: utf-8 -*-

import sys
import re
import numpy as np
import random
import math

import rospy
import rospkg

import yaml
from matplotlib import pyplot as plt

from nav_msgs.msg import OccupancyGrid


if __name__ == '__main__':

    # init ros node
    rospy.init_node('uir_grid_publisher', log_level=rospy.DEBUG)
    rospy.loginfo("Starting UIR grid publisher")

    rospack = rospkg.RosPack()
   
    # load parameters
    map_topic_name = rospy.get_param("~MAP_TOPIC_NAME","/gridmap")
    map_path = rospy.get_param("~MAP_PATH",None)

    map_publisher = rospy.Publisher(map_topic_name, OccupancyGrid, queue_size=1)

    print map_path

    with open(map_path,'r') as map_yaml:
        dct = yaml.safe_load(map_yaml)
        img_path = dct['image']
        resolution = dct['resolution']
        origin = dct['origin']

    img_path = '/'.join(map_path.split('/')[:-1]) + '/' + img_path

    image = plt.imread(img_path)
    grayscale = np.sum(image,axis=2)*(1./3)
    grayscale = np.ones(grayscale.shape) - grayscale

    msg = OccupancyGrid()
    msg.info.resolution = resolution
    msg.info.width = image.shape[1]
    msg.info.height = image.shape[0]
    msg.data = (grayscale.reshape(msg.info.width*msg.info.height)*100).astype(int)

    map_publisher.publish(msg)

    # report loop
    rate = rospy.Rate(1)
    while not rospy.is_shutdown():
        rate.sleep()
        map_publisher.publish(msg)
        rospy.loginfo("%s : I am alive" % rospy.get_name())
    

